﻿using System;
using System.Collections.Generic;
using System.Configuration;
using System.Data;
using System.Linq;
using System.Windows;
using DevExpress.Xpo;
using DevExpress.Data.Filtering;
using DevExpress.Xpo.DB;
using System.IO;
using System.Text;
using System.Collections;

namespace DXGridXPOBinding {
  /// <summary>
  /// Interaction logic for App.xaml
  /// </summary>
  public partial class App : Application {
    protected override void OnStartup(StartupEventArgs e) {
      base.OnStartup(e);

      Global.LogWriter = new LogWriter();

      XpoDefault.DataLayer = new SimpleDataLayer(
        new DataStoreLogger(
        new DataStoreLogger(XpoDefault.GetConnectionProvider(
          MSSqlConnectionProvider.GetConnectionString(".", "DXGridXPOBinding"),
          AutoCreateOption.DatabaseAndSchema),
          Global.LogWriter), 
          File.CreateText("log.txt"))
          );

      // Init some XPO data - only once though
      using (UnitOfWork uow = new UnitOfWork( )) {
        if (uow.FindObject<Customer>(new BinaryOperator("Name", "Harry")) == null) {
          var harry = new Customer(uow) {
            Name = "Harry"
          };
          var annie = new Customer(uow) {
            Name = "Annie"
          };
          var rubberChicken = new Product(uow) {
            Name = "Rubber Chicken"
          };
          var pulley = new Product(uow) {
            Name = "Pulley"
          };
          var bread = new Product(uow) {
            Name = "Bread"
          };
          var butter = new Product(uow) {
            Name = "Butter"
          };
          // create 17000 random orders
          for (int i = 0; i < 17000; i++) {
            CreateRandomOrder(uow, 
              new Customer[] { harry, annie }, 
              new Product[] { rubberChicken, pulley, bread, butter });
          }
          uow.CommitChanges( );
        }
      }
    }
    private void CreateRandomOrder(UnitOfWork uow, Customer[] customers, Product[] products) {
      var r = new Random();
      var order = new Order(uow) {
        Date = new DateTime(2008, r.Next(12) + 1, r.Next(29) + 1),
        Customer = customers[r.Next(customers.Length)]
      };
      int linesCount = r.Next(products.Length) + 1;
      var tempProducts = new List<Product>(products);
      for (int i = 0; i < linesCount; i++) {
        var p = tempProducts[r.Next(tempProducts.Count)];
        tempProducts.Remove(p);
        order.OrderLines.Add(new OrderLine(uow) {
          Count = r.Next(9) + 2,
          Product = p
        });
      }
    }
  }
}